@@ -9,16 +9,14 @@ package MCE::Shared::Array;
 use strict;
 use warnings;
 
-use 5.010001;
-
 no warnings qw( threads recursion uninitialized numeric );
 
-our $VERSION = '1.867_01';
+our $VERSION = '1.001';
 
 ## no critic (TestingAndDebugging::ProhibitNoStrict)
 
-use MCE::Shared::Base ();
-use base 'MCE::Shared::Base::Common';
+use MCE::Shared::Base;
+use bytes;
 
 use overload (
    q("")    => \&MCE::Shared::Base::_stringify,
@@ -190,16 +188,10 @@ sub values {
 
 ###############################################################################
 ## ----------------------------------------------------------------------------
-## assign, mdel, mexists, mget, mset, range, sort
+## mdel, mexists, mget, mset, range, sort
 ##
 ###############################################################################
 
-# assign ( value [, value, ... ] )
-
-sub assign {
-   $_[0]->clear; shift()->push(@_);
-}
-
 # mdel ( index [, index, ... ] )
 
 sub mdel {
@@ -289,27 +281,33 @@ sub sort {
 
    if ( defined wantarray ) {
       if ( $alpha ) { ( $desc )
-         ? CORE::sort { $b cmp $a } @{ $self }
-         : CORE::sort { $a cmp $b } @{ $self };
+       ? CORE::sort { $b cmp $a } @{ $self }
+       : CORE::sort { $a cmp $b } @{ $self };
       }
       else { ( $desc )
-         ? CORE::sort { $b <=> $a } @{ $self }
-         : CORE::sort { $a <=> $b } @{ $self };
+       ? CORE::sort { $b <=> $a } @{ $self }
+       : CORE::sort { $a <=> $b } @{ $self };
       }
    }
 
    # Sort values in-place otherwise, in void context.
 
    elsif ( $alpha ) { ( $desc )
-      ? do { @{ $self } = CORE::sort { $b cmp $a } @{ $self } }
-      : do { @{ $self } = CORE::sort { $a cmp $b } @{ $self } };
+    ? $self->_reorder( CORE::sort { $b cmp $a } @{ $self } )
+    : $self->_reorder( CORE::sort { $a cmp $b } @{ $self } );
    }
    else { ( $desc )
-      ? do { @{ $self } = CORE::sort { $b <=> $a } @{ $self } }
-      : do { @{ $self } = CORE::sort { $a <=> $b } @{ $self } };
+    ? $self->_reorder( CORE::sort { $b <=> $a } @{ $self } )
+    : $self->_reorder( CORE::sort { $a <=> $b } @{ $self } );
    }
 }
 
+sub _reorder {
+   my $self = shift; @{ $self } = @_; 
+
+   return;
+}
+
 ###############################################################################
 ## ----------------------------------------------------------------------------
 ## Sugar API, mostly resembles http://redis.io/commands#string primitives.
@@ -368,6 +366,7 @@ sub len {
    *{ __PACKAGE__.'::shift'   } = \&SHIFT;
    *{ __PACKAGE__.'::unshift' } = \&UNSHIFT;
    *{ __PACKAGE__.'::splice'  } = \&SPLICE;
+
    *{ __PACKAGE__.'::del'     } = \&delete;
    *{ __PACKAGE__.'::merge'   } = \&mset;
    *{ __PACKAGE__.'::vals'    } = \&values;
@@ -389,261 +388,200 @@ MCE::Shared::Array - Array helper class
 
 =head1 VERSION
 
-This document describes MCE::Shared::Array version 1.867_01
-
-=head1 DESCRIPTION
-
-An array helper class for use as a standalone or managed by L<MCE::Shared>.
+This document describes MCE::Shared::Array version 1.001
 
 =head1 SYNOPSIS
 
- # non-shared or local construction for use by a single process
+   # non-shared
+   use MCE::Shared::Array;
 
- use MCE::Shared::Array;
+   my $ar = MCE::Shared::Array->new( @list );
 
- my $ar = MCE::Shared::Array->new( @list );
+   # shared
+   use MCE::Shared;
 
- # construction for sharing with other threads and processes
+   my $ar = MCE::Shared->array( @list );
 
- use MCE::Shared;
+   # oo interface
+   $val   = $ar->set( $index, $val );
+   $val   = $ar->get( $index);
+   $val   = $ar->delete( $index );            # del is an alias for delete
+   $bool  = $ar->exists( $index );
+   void   = $ar->clear();
+   $len   = $ar->len();                       # scalar @{ $ar }
+   $len   = $ar->len( $index );               # length $ar->[ $index ]
+   $val   = $ar->pop();
+   $len   = $ar->push( @list );
+   $val   = $ar->shift();
+   $len   = $ar->unshift( @list );
+   @list  = $ar->splice( $offset, $length, @list );
 
- my $ar = MCE::Shared->array( @list );
+   $ar2   = $ar->clone( @indices );           # @indices is optional
+   $ar3   = $ar->flush( @indices );
+   $iter  = $ar->iterator( @indices );        # ($idx, $val) = $iter->()
+   @keys  = $ar->keys( @indices );
+   %pairs = $ar->pairs( @indices );
+   @vals  = $ar->values( @indices );          # vals is an alias for values
 
- # array-like dereferencing
+   $cnt   = $ar->mdel( @indices );
+   @vals  = $ar->mget( @indices );
+   $bool  = $ar->mexists( @indices );         # true if all indices exists
+   $len   = $ar->mset( $idx/$val pairs );     # merge is an alias for mset
 
- my $val = $ar->[$index];
- $ar->[$index] = $val;
+   @vals  = $ar->range( $start, $stop );
 
- @{$ar} = ();
+   @vals  = $ar->sort();                      # $a <=> $b default
+   @vals  = $ar->sort( "desc" );              # $b <=> $a
+   @vals  = $ar->sort( "alpha" );             # $a cmp $b
+   @vals  = $ar->sort( "alpha desc" );        # $b cmp $a
 
- # OO interface
+   # search capability key/val { =~ !~ eq ne lt le gt ge == != < <= > >= }
+   # key/val means to match against actual key/val respectively
+   # do not add quotes inside the string unless intended literally
+   # do not mix :AND(s) and :OR(s) together
 
- $val   = $ar->set( $index, $val );
- $val   = $ar->get( $index);
- $val   = $ar->delete( $index );            # del is an alias for delete
- $bool  = $ar->exists( $index );
- void   = $ar->clear();
- $len   = $ar->len();                       # scalar @{ $ar }
- $len   = $ar->len( $index );               # length $ar->[ $index ]
- $val   = $ar->pop();
- $len   = $ar->push( @list );
- $val   = $ar->shift();
- $len   = $ar->unshift( @list );
- @list  = $ar->splice( $offset, $length, @list );
+   @keys  = $ar->keys( "key =~ /$pattern/i" );
+   @keys  = $ar->keys( "key !~ /$pattern/i" );
+   @keys  = $ar->keys( "val =~ /$pattern/i" );
+   @keys  = $ar->keys( "val !~ /$pattern/i" );
 
- $ar2   = $ar->clone( @indices );           # @indices is optional
- $ar3   = $ar->flush( @indices );
- $iter  = $ar->iterator( @indices );        # ($idx, $val) = $iter->()
- @keys  = $ar->keys( @indices );
- %pairs = $ar->pairs( @indices );
- @vals  = $ar->values( @indices );          # vals is an alias for values
+   %pairs = $ar->pairs( "key == $number" );
+   %pairs = $ar->pairs( "key != $number :AND val > 100" );
+   %pairs = $ar->pairs( "key <  $number :OR key > $number" );
+   %pairs = $ar->pairs( "val <= $number" );
+   %pairs = $ar->pairs( "val >  $number" );
+   %pairs = $ar->pairs( "val >= $number" );
 
- $len   = $ar->assign( $idx/$val pairs );   # equivalent to ->clear, ->push
- $cnt   = $ar->mdel( @indices );
- @vals  = $ar->mget( @indices );
- $bool  = $ar->mexists( @indices );         # true if all indices exists
- $len   = $ar->mset( $idx/$val pairs );     # merge is an alias for mset
+   @vals  = $ar->values( "key eq $string" );
+   @vals  = $ar->values( "key ne $string with space" );
+   @vals  = $ar->values( "key lt $string :OR val =~ /$pat1|$pat2/" );
+   @vals  = $ar->values( "val le $string :AND val eq foo bar" );
+   @vals  = $ar->values( "val gt $string" );
+   @vals  = $ar->values( "val ge $string" );
 
- @vals  = $ar->range( $start, $stop );
+   # sugar methods without having to call set/get explicitly
 
- @vals  = $ar->sort();                      # $a <=> $b default
- @vals  = $ar->sort( "desc" );              # $b <=> $a
- @vals  = $ar->sort( "alpha" );             # $a cmp $b
- @vals  = $ar->sort( "alpha desc" );        # $b cmp $a
+   $len   = $ar->append( $index, $string );   #   $val .= $string
+   $val   = $ar->decr( $index );              # --$val
+   $val   = $ar->decrby( $index, $number );   #   $val -= $number
+   $val   = $ar->getdecr( $index );           #   $val--
+   $val   = $ar->getincr( $index );           #   $val++
+   $val   = $ar->incr( $index );              # ++$val
+   $val   = $ar->incrby( $index, $number );   #   $val += $number
+   $old   = $ar->getset( $index, $new );      #   $o = $v, $v = $n, $o
 
- # included, sugar methods without having to call set/get explicitly
+=head1 DESCRIPTION
 
- $len   = $ar->append( $index, $string );   #   $val .= $string
- $val   = $ar->decr( $index );              # --$val
- $val   = $ar->decrby( $index, $number );   #   $val -= $number
- $val   = $ar->getdecr( $index );           #   $val--
- $val   = $ar->getincr( $index );           #   $val++
- $val   = $ar->incr( $index );              # ++$val
- $val   = $ar->incrby( $index, $number );   #   $val += $number
- $old   = $ar->getset( $index, $new );      #   $o = $v, $v = $n, $o
-
- # pipeline, provides atomicity for shared objects, MCE::Shared v1.09+
-
- @vals  = $ar->pipeline(                    # ( "a_a", "b_b", "c_c" )
-    [ "set", 0 => "a_a" ],
-    [ "set", 1 => "b_b" ],
-    [ "set", 2 => "c_c" ],
-    [ "mget", qw/ 0 1 2 / ]
- );
-
-For normal array behavior, the TIE interface is supported.
-
- # non-shared or local construction for use by a single process
-
- use MCE::Shared::Array;
-
- tie my @ar, "MCE::Shared::Array";
-
- # construction for sharing with other threads and processes
-
- use MCE::Shared;
-
- tie my @ar, "MCE::Shared";
-
- # usage
-
- my $val;
-
- if ( !defined ( $val = $ar[some_index] ) ) {
-    $val = $ar[some_index] = "some_value";
- }
-
- $ar[some_index] = 0;
-
- tied(@ar)->incrby("some_index", 20);
- tied(@ar)->incrby(some_index => 20);
+An array helper class for use with L<MCE::Shared>.
 
 =head1 SYNTAX for QUERY STRING
 
-Several methods take a query string for an argument. The format of the string
-is described below. In the context of sharing, the query mechanism is beneficial
-for the shared-manager process. It is able to perform the query where the data
-resides versus the client-process grep locally involving lots of IPC.
+Several methods in C<MCE::Shared::Array> take a query string for an argument.
+The format of the string is quoteless. Therefore, any quotes inside the string
+is treated literally.
 
- o Basic demonstration
+   o Basic demonstration: @keys = $ar->keys( "val =~ /pattern/" );
+   o Supported operators: =~ !~ eq ne lt le gt ge == != < <= > >=
+   o Multiple expressions are delimited by :AND or :OR.
 
-   @keys = $ar->keys( "query string given here" );
-   @keys = $ar->keys( "val =~ /pattern/" );
+     "key =~ /pattern/i :AND val =~ /pattern/i"
+     "key =~ /pattern/i :AND val eq foo bar"     # val eq "foo bar"
+     "val eq foo baz :OR key !~ /pattern/i"
 
- o Supported operators: =~ !~ eq ne lt le gt ge == != < <= > >=
- o Multiple expressions delimited by :AND or :OR, mixed case allowed
+     * key matches on indices in the array
+     * val matches on values
 
-   "key == 3 :or (val > 5 :and val < 9)"
-   "key =~ /pattern/i :And val =~ /pattern/i"
-   "val eq foo baz :OR key !~ /pattern/i"
+=over 3
 
-   * key matches on indices in the array
-   * likewise, val matches on values
+=item * The modifiers C<:AND> and C<:OR> may be mixed case. e.g. C<:And>
 
- o Quoting is optional inside the string
+=item * Mixing C<:AND> and C<:OR> in the query is not supported.
 
-   "key =~ /pattern/i :AND val eq 'foo bar'"   # val eq "foo bar"
-   "key =~ /pattern/i :AND val eq foo bar"     # val eq "foo bar"
-
-Examples.
-
- # search capability key/val: =~ !~ eq ne lt le gt ge == != < <= > >=
- # key/val means to match against actual key/val respectively
-
- @keys  = $ar->keys( "key == 3 :or (val > 5 :and val < 9)" );
-
- @keys  = $ar->keys( "key =~ /$pattern/i" );
- @keys  = $ar->keys( "key !~ /$pattern/i" );
- @keys  = $ar->keys( "val =~ /$pattern/i" );
- @keys  = $ar->keys( "val !~ /$pattern/i" );
-
- %pairs = $ar->pairs( "key == $number" );
- %pairs = $ar->pairs( "key != $number :and val > 100" );
- %pairs = $ar->pairs( "key <  $number :or key > $number" );
- %pairs = $ar->pairs( "val <= $number" );
- %pairs = $ar->pairs( "val >  $number" );
- %pairs = $ar->pairs( "val >= $number" );
-
- @vals  = $ar->vals( "key eq $string" );
- @vals  = $ar->vals( "key ne $string with space" );
- @vals  = $ar->vals( "key lt $string :or val =~ /$pat1|$pat2/" );
- @vals  = $ar->vals( "val le $string :and val eq 'foo bar'" );
- @vals  = $ar->vals( "val le $string :and val eq foo bar" );
- @vals  = $ar->vals( "val gt $string" );
- @vals  = $ar->vals( "val ge $string" );
+=back
 
 =head1 API DOCUMENTATION
 
 This module may involve TIE when accessing the object via array-like behavior.
 Only shared instances are impacted if doing so. Although likely fast enough for
-many use cases, the OO interface is recommended for best performance.
+many use cases, use the OO interface if better performance is desired.
 
-=head2 MCE::Shared::Array->new ( val [, val, ... ] )
+=over 3
 
-=head2 MCE::Shared->array ( val [, val, ... ] )
+=item new ( val [, val, ... ] )
 
 Constructs a new object, with an optional list of values.
 
- # non-shared or local construction for use by a single process
+   # non-shared
+   use MCE::Shared::Array;
 
- use MCE::Shared::Array;
+   $ar = MCE::Shared::Array->new( @list );
+   $ar = MCE::Shared::Array->new( );
 
- $ar = MCE::Shared::Array->new( @list );
- $ar = MCE::Shared::Array->new( );
+   # shared
+   use MCE::Shared;
 
- # construction for sharing with other threads and processes
+   $ar = MCE::Shared->array( @list );
+   $ar = MCE::Shared->array( );
 
- use MCE::Shared;
-
- $ar = MCE::Shared->array( @list );
- $ar = MCE::Shared->array( );
-
-=head2 assign ( value [, value, ... ] )
-
-Clears the list, then appends one or multiple values and returns the new length.
-This is equivalent to C<clear>, C<push>.
-
- $len = $ar->assign( "val1", "val2" );
- $len = @{$ar} = ( "val1", "val2" );
-
-API available since 1.007.
-
-=head2 clear
+=item clear
 
 Removes all elements from the array.
 
- $ar->clear;
- @{$ar} = ();
+   $ar->clear;
+   @{$ar} = ();
 
-=head2 clone ( index [, index, ... ] )
+=item clone ( index [, index, ... ] )
 
 Creates a shallow copy, a C<MCE::Shared::Array> object. It returns an exact
 copy if no arguments are given. Otherwise, the object includes only the given
 indices in the same order. Indices that do not exist in the array will have
 the C<undef> value.
 
- $ar2 = $ar->clone( 0, 1 );
- $ar2 = $ar->clone;
+   $ar2 = $ar->clone( 0, 1 );
+   $ar2 = $ar->clone;
 
-=head2 delete ( index )
+=item delete ( index )
 
 Deletes and returns the value associated by index or C<undef> if index exceeds
 the size of the list.
 
- $val = $ar->delete( 20 );
- $val = delete $ar->[ 20 ];
+   $val = $ar->delete( 20 );
+   $val = delete $ar->[ 20 ];
 
-=head2 del
+=item del
 
 C<del> is an alias for C<delete>.
 
-=head2 exists ( index )
+=item exists ( index )
 
 Determines if an element by its index exists in the array. The behavior is
 strongly tied to the use of delete on lists.
 
- $ar->push(qw/ value0 value1 value2 value3 /);
+   $ar->push(qw/ value0 value1 value2 value3 /);
 
- $ar->exists( 2 );   # True
- $ar->delete( 2 );   # value2
- $ar->exists( 2 );   # False
+   $ar->exists( 2 );     # True
+   $ar->exists( 2, 3 );  # True
+   $ar->delete( 2 );     # value2
 
- $ar->exists( 3 );   # True
- exists $ar->[ 3 ];  # True
+   $ar->exists( 2 );     # False
+   $ar->exists( 2, 3 );  # False
+   $ar->exists( 3 );     # True
 
-=head2 flush ( index [, index, ... ] )
+   exists $ar->[ 3 ];
+
+=item flush ( index [, index, ... ] )
 
 Same as C<clone>. Though, clears all existing items before returning.
 
-=head2 get ( index )
+=item get ( index )
 
 Gets the value of an element by its index or C<undef> if the index does not
 exists.
 
- $val = $ar->get( 2 );
- $val = $ar->[ 2 ];
+   $val = $ar->get( 2 );
+   $val = $ar->[ 2 ];
 
-=head2 iterator ( index [, index, ... ] )
+=item iterator ( index [, index, ... ] )
 
 Returns a code reference for iterating a list of index-value pairs stored in
 the array when no arguments are given. Otherwise, returns a code reference for
@@ -654,191 +592,141 @@ The list of indices to return is set when the closure is constructed. New
 indices added later are not included. Subsequently, the C<undef> value is
 returned for deleted indices.
 
- $iter = $ar->iterator;
- $iter = $ar->iterator( 0, 1 );
+   $iter = $ar->iterator;
+   $iter = $ar->iterator( 0, 1 );
 
- while ( my ( $index, $val ) = $iter->() ) {
-    ...
- }
+   while ( my ( $index, $val ) = $iter->() ) {
+      ...
+   }
 
-=head2 iterator ( "query string" )
+=item iterator ( "query string" )
 
 Returns a code reference for iterating a list of index-value pairs that match
 the given criteria. It returns an empty list if the search found nothing.
 The syntax for the C<query string> is described above.
 
- $iter = $ar->iterator( "val eq some_value" );
- $iter = $ar->iterator( "key >= 50 :AND val =~ /sun|moon|air|wind/" );
- $iter = $ar->iterator( "val eq sun :OR val eq moon :OR val eq foo" );
- $iter = $ar->iterator( "key =~ /$pattern/" );
+   $iter = $ar->iterator( "val eq some_value" );
+   $iter = $ar->iterator( "key >= 50 :AND val =~ /sun|moon|air|wind/" );
+   $iter = $ar->iterator( "val eq sun :OR val eq moon :OR val eq foo" );
+   $iter = $ar->iterator( "key =~ /$pattern/" );
 
- while ( my ( $index, $val ) = $iter->() ) {
-    ...
- }
+   while ( my ( $index, $val ) = $iter->() ) {
+      ...
+   }
 
-=head2 keys ( index [, index, ... ] )
+=item keys ( index [, index, ... ] )
 
 Returns all indices in the array when no arguments are given. Otherwise,
 returns the given indices in the same order. Indices that do not exist will
 have the C<undef> value. In scalar context, returns the size of the array.
 
- @keys = $ar->keys( 0, 1 );
+   @keys = $ar->keys;
+   @keys = $ar->keys( 0, 1 );
+   $len  = $ar->keys;
 
- @keys = $ar->keys;     # faster
- @keys = keys @{$ar};   # involves TIE overhead
-
- $len  = $ar->keys;     # ditto
- $len  = keys @{$ar};
-
-=head2 keys ( "query string" )
+=item keys ( "query string" )
 
 Returns only indices that match the given criteria. It returns an empty list
 if the search found nothing. The syntax for the C<query string> is described
 above. In scalar context, returns the size of the resulting list.
 
- @keys = $ar->keys( "val eq some_value" );
- @keys = $ar->keys( "key >= 50 :AND val =~ /sun|moon|air|wind/" );
- @keys = $ar->keys( "val eq sun :OR val eq moon :OR val eq foo" );
- $len  = $ar->keys( "key =~ /$pattern/" );
+   @keys = $ar->keys( "val eq some_value" );
+   @keys = $ar->keys( "key >= 50 :AND val =~ /sun|moon|air|wind/" );
+   @keys = $ar->keys( "val eq sun :OR val eq moon :OR val eq foo" );
+   $len  = $ar->keys( "key =~ /$pattern/" );
 
-=head2 len ( index )
+=item len ( index )
 
 Returns the size of the array when no arguments are given. For the given
 index, returns the length of the value stored at index or the C<undef> value
 if the index does not exists.
 
- $len = $ar->len;
- $len = $ar->len( 0 );
- $len = length $ar->[ 0 ];
+   $len = $ar->len;
+   $len = $ar->len( 0 );
+   $len = length $ar->[ 0 ];
 
-=head2 mdel ( index [, index, ... ] )
+=item mdel ( index [, index, ... ] )
 
 Deletes one or more elements by its index and returns the number of indices
 deleted. A given index which does not exist in the list is not counted.
 
- $cnt = $ar->mdel( 0, 1 );
+   $cnt = $ar->mdel( 0, 1 );
 
-=head2 mexists ( index [, index, ... ] )
+=item mexists ( index [, index, ... ] )
 
 Returns a true value if all given indices exists in the list. A false value is
 returned otherwise.
 
- if ( $ar->mexists( 0, 1 ) ) { ... }
+   if ( $ar->mexists( 0, 1 ) ) { ... }
 
-=head2 mget ( index [, index, ... ] )
+=item mget ( index [, index, ... ] )
 
 Gets multiple values from the list by its index. It returns C<undef> for indices
 which do not exists in the list.
 
- ( $val1, $val2 ) = $ar->mget( 0, 1 );
+   ( $val1, $val2 ) = $ar->mget( 0, 1 );
 
-=head2 mset ( index, value [, index, value, ... ] )
+=item mset ( index, value [, index, value, ... ] )
 
 Sets multiple index-value pairs in the list and returns the length of the list.
 
- $len = $ar->mset( 0 => "val1", 1 => "val2" );
+   $len = $ar->mset( 0 => "val1", 1 => "val2" );
 
-=head2 merge
+=item merge
 
 C<merge> is an alias for C<mset>.
 
-=head2 pairs ( index [, index, ... ] )
+=item pairs ( "query string" )
 
 Returns index-value pairs in the array when no arguments are given. Otherwise,
 returns index-value pairs for the given indices in the same order. Indices that
 do not exist will have the C<undef> value. In scalar context, returns the size
 of the array.
 
- @pairs = $ar->pairs( 0, 1 );
+   @pairs = $ar->pairs;
+   @pairs = $ar->pairs( 0, 1 );
+   $len   = $ar->pairs;
 
- @pairs = $ar->pairs;
- $len   = $ar->pairs;
-
-=head2 pairs ( "query string" )
+=item pairs ( index [, index, ... ] )
 
 Returns only index-value pairs that match the given criteria. It returns an
 empty list if the search found nothing. The syntax for the C<query string> is
 described above. In scalar context, returns the size of the resulting list.
 
- @pairs = $ar->pairs( "val eq some_value" );
- @pairs = $ar->pairs( "key >= 50 :AND val =~ /sun|moon|air|wind/" );
- @pairs = $ar->pairs( "val eq sun :OR val eq moon :OR val eq foo" );
- $len   = $ar->pairs( "key =~ /$pattern/" );
+   @pairs = $ar->pairs( "val eq some_value" );
+   @pairs = $ar->pairs( "key >= 50 :AND val =~ /sun|moon|air|wind/" );
+   @pairs = $ar->pairs( "val eq sun :OR val eq moon :OR val eq foo" );
+   $len   = $ar->pairs( "key =~ /$pattern/" );
 
-=head2 pipeline ( [ func1, @args ], [ func2, @args ], ... )
-
-Combines multiple commands for the object to be processed serially. For shared
-objects, the call is made atomically due to single IPC to the shared-manager
-process. The C<pipeline> method is fully C<wantarray>-aware and receives a list
-of commands and their arguments. In scalar or list context, it returns data
-from the last command in the pipeline.
-
- @vals = $ar->pipeline(                     # ( "a_a", "b_b", "c_c" )
-    [ "set", 0 => "a_a" ],
-    [ "set", 1 => "b_b" ],
-    [ "set", 2 => "c_c" ],
-    [ "mget", qw/ 0 1 2 / ]
- );
-
- $len = $ar->pipeline(                      # 3, same as $ar->len
-    [ "set", 0 => "i_i" ],
-    [ "set", 1 => "j_j" ],
-    [ "set", 2 => "k_k" ],
-    [ "len" ]
- );
-
- $ar->pipeline(
-    [ "set", 0 => "m_m" ],
-    [ "set", 1 => "n_n" ],
-    [ "set", 2 => "o_o" ]
- );
-
-Current API available since 1.809.
-
-=head2 pipeline_ex ( [ func1, @args ], [ func2, @args ], ... )
-
-Same as C<pipeline>, but returns data for every command in the pipeline.
-
- @vals = $ar->pipeline_ex(                  # ( "a_a", "b_b", "c_c" )
-    [ "set", 0 => "a_a" ],
-    [ "set", 1 => "b_b" ],
-    [ "set", 2 => "c_c" ]
- );
-
-Current API available since 1.809.
-
-=head2 pop
+=item pop
 
 Removes and returns the last value of the list. If there are no elements in the
 list, returns the undefined value.
 
- $val = $ar->pop;
- $val = pop @{$ar};
+   $val = $ar->pop;
 
-=head2 push ( value [, value, ... ] )
+=item push ( value [, value, ... ] )
 
 Appends one or multiple values to the tail of the list and returns the new
 length.
 
- $len = $ar->push( "val1", "val2" );
- $len = push @{$ar}, "val1", "val2";
+   $len = $ar->push( "val1", "val2" );
 
-=head2 set ( index, value )
+=item set ( index, value )
 
 Sets the value of the given array index and returns its new value.
 
- $val = $ar->set( 2, "value" );
- $val = $ar->[ 2 ] = "value";
+   $val = $ar->set( 2, "value" );
+   $val = $ar->[ 2 ] = "value";
 
-=head2 shift
+=item shift
 
 Removes and returns the first value of the list. If there are no elements in the
 list, returns the undefined value.
 
- $val = $ar->shift;
- $val = shift @{$ar};
+   $val = $ar->shift;
 
-=head2 range ( start, stop )
+=item range ( start, stop )
 
 Returns the specified elements of the list. The offsets C<start> and C<stop>
 can also be negative numbers indicating offsets starting at the end of the
@@ -848,136 +736,134 @@ An empty list is returned if C<start> is larger than the end of the list.
 C<stop> is set to the last index of the list if larger than the actual end
 of the list.
 
- @list = $ar->range( 20, 29 );
- @list = $ar->range( -4, -1 );
+   @list = $ar->range( 20, 29 );
+   @list = $ar->range( -4, -1 );
 
-=head2 sort ( "BY val [ ASC | DESC ] [ ALPHA ]" )
+=item sort ( "BY val [ ASC | DESC ] [ ALPHA ]" )
 
 Returns sorted values in list context, leaving the elements intact. In void
 context, sorts the list in-place. By default, sorting is numeric when no
 arguments are given. The C<BY val> modifier is optional and may be omitted.
 
- @vals = $ar->sort( "BY val" );
+   @vals = $ar->sort( "BY val" );
 
- $ar->sort();
+   $ar->sort();
 
 If the list contains string values and you want to sort them lexicographically,
 specify the C<ALPHA> modifier.
 
- @vals = $ar->sort( "BY val ALPHA" );
+   @vals = $ar->sort( "BY val ALPHA" );
 
- $ar->sort( "ALPHA" );
+   $ar->sort( "ALPHA" );
 
 The default is C<ASC> for sorting the list from small to large. In order to
 sort the list from large to small, specify the C<DESC> modifier.
 
- @vals = $ar->sort( "DESC ALPHA" );
+   @vals = $ar->sort( "DESC ALPHA" );
 
- $ar->sort( "DESC ALPHA" );
+   $ar->sort( "DESC ALPHA" );
 
-=head2 splice ( offset [, length [, list ] ] )
+=item splice ( offset [, length [, list ] ] )
 
 Removes the elements designated by C<offset> and C<length> from the array, and
 replaces them with the elements of C<list>, if any. The behavior is similar to
 the Perl C<splice> function.
 
- @items = $ar->splice( 20, 2, @list );
- @items = $ar->splice( 20, 2 );
- @items = $ar->splice( 20 );
+   @items = $ar->splice( 20, 2, @list );
+   @items = $ar->splice( 20, 2 );
+   @items = $ar->splice( 20 );
 
-=head2 unshift ( value [, value, ... ] )
+=item unshift ( value [, value, ... ] )
 
 Prepends one or multiple values to the head of the list and returns the new
 length.
 
- $len = $ar->unshift( "val1", "val2" );
- $len = unshift @{$ar}, "val1", "val2";
+   $len = $ar->unshift( "val1", "val2" );
 
-=head2 values ( index [, index, ... ] )
+=item values ( index [, index, ... ] )
 
 Returns all values in the array when no arguments are given. Otherwise, returns
 values for the given indices in the same order. Indices that do not exist will
 have the C<undef> value. In scalar context, returns the size of the array.
 
- @vals = $ar->values( 0, 1 );
+   @vals = $ar->values;
+   @vals = $ar->values( 0, 1 );
+   $len  = $ar->values;
 
- @vals = $ar->values;     # faster
- @vals = values @{$ar};   # involves TIE overhead
-
- $len  = $ar->values;     # ditto
- $len  = values @{$ar};
-
-=head2 values ( "query string" )
+=item values ( "query string" )
 
 Returns only values that match the given criteria. It returns an empty list
 if the search found nothing. The syntax for the C<query string> is described
 above. In scalar context, returns the size of the resulting list.
 
- @keys = $ar->values( "val eq some_value" );
- @keys = $ar->values( "key >= 50 :AND val =~ /sun|moon|air|wind/" );
- @keys = $ar->values( "val eq sun :OR val eq moon :OR val eq foo" );
- $len  = $ar->values( "key =~ /$pattern/" );
+   @keys = $ar->values( "val eq some_value" );
+   @keys = $ar->values( "key >= 50 :AND val =~ /sun|moon|air|wind/" );
+   @keys = $ar->values( "val eq sun :OR val eq moon :OR val eq foo" );
+   $len  = $ar->values( "key =~ /$pattern/" );
 
-=head2 vals
+=item vals
 
 C<vals> is an alias for C<values>.
 
+=back
+
 =head1 SUGAR METHODS
 
 This module is equipped with sugar methods to not have to call C<set>
-and C<get> explicitly. In shared context, the benefit is atomicity and
-reduction in inter-process communication.
-
-The API resembles a subset of the Redis primitives
+and C<get> explicitly. The API resembles a subset of the Redis primitives
 L<http://redis.io/commands#strings> with key representing the array index.
 
-=head2 append ( key, string )
+=over 3
+
+=item append ( key, string )
 
 Appends a value to a key and returns its new length.
 
- $len = $ar->append( 0, "foo" );
+   $len = $ar->append( 0, "foo" );
 
-=head2 decr ( key )
+=item decr ( key )
 
 Decrements the value of a key by one and returns its new value.
 
- $num = $ar->decr( 0 );
+   $num = $ar->decr( 0 );
 
-=head2 decrby ( key, number )
+=item decrby ( key, number )
 
 Decrements the value of a key by the given number and returns its new value.
 
- $num = $ar->decrby( 0, 2 );
+   $num = $ar->decrby( 0, 2 );
 
-=head2 getdecr ( key )
+=item getdecr ( key )
 
 Decrements the value of a key by one and returns its old value.
 
- $old = $ar->getdecr( 0 );
+   $old = $ar->getdecr( 0 );
 
-=head2 getincr ( key )
+=item getincr ( key )
 
 Increments the value of a key by one and returns its old value.
 
- $old = $ar->getincr( 0 );
+   $old = $ar->getincr( 0 );
 
-=head2 getset ( key, value )
+=item getset ( key, value )
 
 Sets the value of a key and returns its old value.
 
- $old = $ar->getset( 0, "baz" );
+   $old = $ar->getset( 0, "baz" );
 
-=head2 incr ( key )
+=item incr ( key )
 
 Increments the value of a key by one and returns its new value.
 
- $num = $ar->incr( 0 );
+   $num = $ar->incr( 0 );
 
-=head2 incrby ( key, number )
+=item incrby ( key, number )
 
 Increments the value of a key by the given number and returns its new value.
 
- $num = $ar->incrby( 0, 2 );
+   $num = $ar->incrby( 0, 2 );
+
+=back
 
 =head1 CREDITS
 
